@@ -41,15 +41,17 @@ QString Frame::toHtml() {
 QVariant Frame::evaluateJavaScript(const QString &js, bool expectLoad, int timeout) {
     QVariant result = p_frame->evaluateJavaScript(js);
 
-    Timeout *t = new Timeout(&m_loop, timeout);
-    EventProcessor *ep = new EventProcessor();
+    Timeout t(&m_loop, timeout);
+    EventProcessor ep;
+
+    t.start();
+    ep.start();
 
     if (expectLoad) {
         m_loop.exec();
     }
 
-    delete t;
-    delete ep;
+    ep.stop();
     return result;
 }
 
