@@ -3,22 +3,24 @@
 namespace ph {
 
 Timeout::Timeout(QEventLoop *loop, int msecs, QObject *parent): QObject(parent) {
-    p_loop = loop;
-
     p_timer = new QTimer();
-    p_timer->setInterval(msecs);
-    p_timer->setSingleShot(true);
-
-    connect(p_timer, &QTimer::timeout, this, &Timeout::handleTimeout);
-
-    p_timer->start();
+    p_loop = loop;
+    m_interval = msecs;
 }
 
 Timeout::~Timeout() {
     if (p_timer->isActive()) {
         p_timer->stop();
     }
-    delete p_timer;
+    p_timer->deleteLater();
+}
+
+void Timeout::start() {
+    p_timer->setInterval(m_interval);
+    p_timer->setSingleShot(true);
+
+    connect(p_timer, &QTimer::timeout, this, &Timeout::handleTimeout);
+    p_timer->start();
 }
 
 void Timeout::handleTimeout() {
