@@ -12,9 +12,12 @@ public:
     Timeout(QEventLoop *loop, int msecs=5000, QObject *parent=0);
     ~Timeout();
 
+    void start();
+
 private:
     QTimer *p_timer;
     QEventLoop *p_loop;
+    int m_interval;
 
 private slots:
     void handleTimeout();
