@@ -8,9 +8,8 @@ import os
 import json
 
 def load_library():
-    cwd = os.path.dirname(os.path.abspath(__file__))
-    libdir = os.path.join(cwd, "_phantompy.so")
-    return ctypes.CDLL(libdir)
+    libpath = ctypes.util.find_library('phantompy')
+    return ctypes.CDLL(libpath)
 
 
 try:
@@ -22,6 +21,9 @@ try:
     _library.ph_context_free.argtypes = []
     _library.ph_context_free.restype = None
 
+    _library.ph_context_process_events.argtypes = [c_int]
+    _library.ph_context_process_events.restype = None
+
     _library.ph_context_clear_cookies.argtypes = []
     _library.ph_context_clear_cookies.restype = None
 
