@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+from __future__ import unicode_literals
+
 import json
 
 from .api import library as lib
@@ -133,6 +135,47 @@ class WebElement(object):
         if self.has_attr(attrname):
             lib.ph_webelement_remove_attr(self.ptr, util.force_bytes(attrname))
 
+    @util.as_dict
+    def get_attrs(self):
+        """
+        Get all attributes as python dict.
+        :rtype: dict
+        """
+
+        attr_names = lib.ph_webelement_get_attrnames(self.ptr)
+        for name in util.force_text(attr_names).split():
+            value = lib.ph_webelement_get_attr(self.ptr, util.force_bytes(name))
+            yield name, util.force_text(value)
+
+    def get_attr(self, name, **kwargs):
+        if kwargs and "default" not in kwargs:
+            raise ValueError("Invalid arguments: {0}".format(
+                                    ",".join(kwargs.keys())))
+
+        attrs = util.force_text(lib.ph_webelement_get_attrnames(self.ptr)).split()
+        if name not in attrs:
+            if "default" in kwargs:
+                return kwargs["default"]
+            raise AttributeError("Attribute {0} does not exists".format(name))
+
+        value = lib.ph_webelement_get_attr(self.ptr, util.force_bytes(name))
+        return util.force_text(value)
+
+    def set_attr(self, name, value):
+        if not isinstance(value, (util.string_type, util.bytes_type)):
+            value = str(value)
+
+        lib.ph_webelement_set_attr(self.ptr,
+                                   util.force_bytes(name),
+                                   util.force_bytes(value))
+
+    def set_attrs(self, attrs):
+        if not isinstance(attrs, dict):
+            raise TypeError("attr must be a dict instance")
+
+        for key, value in attrs.items():
+            self.set_attr(key, value)
+
     def append(self, element):
         """
         Append element or raw html to the current dom element.
@@ -243,18 +286,6 @@ class WebElement(object):
         ptr = lib.ph_webelement_previous(self.ptr)
         return WebElement(ptr, self.frame)
 
-    @util.as_dict
-    def get_attrs(self):
-        """
-        Get all attributes as python dict.
-        :rtype: dict
-        """
-
-        attr_names = lib.ph_webelement_get_attrnames(self.ptr)
-        for name in util.force_text(attr_names).split():
-            value = lib.ph_webelement_get_attr(self.ptr, util.force_bytes(name))
-            yield name, util.force_text(value)
-
     def inner_html(self):
         """
         Get inner dom structure as html.
@@ -286,6 +317,21 @@ class WebElement(object):
         result = lib.ph_webelement_is_null(self.ptr)
         return util.int_to_bool(result)
 
+    def cssselect_first(self, selector):
+        selector = util.force_bytes(selector)
+
+        c_ptr = lib.ph_webelement_find_all(self.ptr, selector)
+        c_size = lib.ph_webcollection_size(c_ptr)
+
+        if c_size == 0:
+            raise ValueError("Element({0}) not found".format(
+                                                    util.force_text(selector)))
+
+        el_ptr = lib.ph_webcollection_get_webelement(c_ptr, 0)
+        lib.ph_webcollection_free(c_ptr)
+
+        return WebElement(el_ptr, self)
+
     @util.as_list
     def cssselect(self, selector):
         """
@@ -306,8 +352,3 @@ class WebElement(object):
             yield WebElement(el_ptr, self)
 
         lib.ph_webcollection_free(c_ptr)
-
-    def evaluate(self, js, expect_load=False, timeout=6000):
-        js = util.force_bytes(js)
-        result = lib.ph_webelement_evaluate_javascript(self.ptr, js, expect_load, timeout)
-        return json.loads(util.force_text(result))
